<?php

namespace Bixo\Organization\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Organization\Http\Resources\OrganizationResource;
use Bixo\Organization\Http\Resources\OrganizationsCollection;
use Bixo\Organization\Scopes\OrganizationPublicScope;
use Bixo\Organization\Models\Organization;

class OrganizationPublicController extends BaseController
{

    /**
     * Show organization's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Organization::pushScope(new RequestScope())
            ->pushScope(new OrganizationPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $organizations = new OrganizationsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('organization::organization.names'))
            ->view('organization::public.organization.index')
            ->data(compact('organizations', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show organization.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Organization::findBySlug($slug);
        $data = new OrganizationResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('organization::organization.name'))
            ->view('organization::public.organization.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
