<?php

namespace Bixo\Organization\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Organization\Events\OrganizationWorkflow as OrganizationWorkflowEvent;
use Bixo\Organization\Notifications\OrganizationWorkflow as OrganizationWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OrganizationWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OrganizationWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $organization is submitted.
     *
     * @param OrganizationWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OrganizationWorkflowEvent $event)
    {
        $client = $event->organization->client;
        Notification::send($client, new OrganizationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $organization is published.
     *
     * @param OrganizationWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OrganizationWorkflowEvent $event)
    {
        $client = $event->organization->client;
        Notification::send($client, new OrganizationWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $organization is approved.
     *
     * @param OrganizationWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OrganizationWorkflowEvent $event)
    {
        $client = $event->organization->client;
        Notification::send($client, new OrganizationWorkflowNotification($event));
    }

    /**
     * Handles the $organization workflow event as a listener.
     *
     * @param OrganizationWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OrganizationWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
