<?php
namespace Bixo\Organization\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Organization\Events\OrganizationAction as OrganizationActionEvent;
use Bixo\Organization\Models\Organization;

class OrganizationAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $organization;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param OrganizationActionEvent $organization
     */
    public function __construct(OrganizationActionEvent $organization)
    {
        $this->action = $event->action;
        $this->organization = $organization;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Organization Approved - ' . config('app.name'))
            ->view('organization::organization.email.action', ['data' => $this->organization]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
