<?php

namespace Bixo\Organization\Policies;

use Bixo\Organization\Models\Organization;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait OrganizationWorkflow
{

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.reject')) {
            return true;
        }

        return false;
    }

}
